=== modified file 'diff.py'
--- diff.py	2008-05-09 03:34:41 +0000
+++ diff.py	2008-05-10 03:23:00 +0000
@@ -474,6 +474,12 @@
         info_dialog(_('Merge successful'),
                     _('All changes applied successfully.'))
 
+    def _conflicts(self):
+        warning_dialog(_('Conflicts encountered'),
+                       _('Please resolve the conflicts manually'
+                         ' before committing.'))
+
+
     def _get_save_path(self, basename):
         d = gtk.FileChooserDialog('Save As', self,
                                   gtk.FILE_CHOOSER_ACTION_SAVE,
@@ -572,10 +578,8 @@
                 if conflict_count == 0:
                     self.window._merge_successful()
                 else:
+                    self.window._conflicts()
                     # There are conflicts to be resolved.
-                    warning_dialog(_('Conflicts encountered'),
-                                   _('Please resolve the conflicts manually'
-                                     ' before committing.'))
                 self.window.destroy()
             except Exception, e:
                 error_dialog('Error', str(e))

=== modified file 'tests/test_diff.py'
--- tests/test_diff.py	2008-05-09 03:41:19 +0000
+++ tests/test_diff.py	2008-05-10 03:23:00 +0000
@@ -101,6 +101,7 @@
 class MockWindow(object):
     def __init__(self):
         self.diff = MockDiffWidget()
+        self.merge_successful = False
 
     def set_title(self, title):
         self.title = title
@@ -117,6 +118,9 @@
     def _merge_successful(self):
         self.merge_successful = True
 
+    def _conflicts(self):
+        self.conflicts = True
+
 
 class TestDiffController(tests.TestCaseWithTransport):
 
@@ -153,11 +157,12 @@
 
 class TestMergeDirectiveController(tests.TestCaseWithTransport):
 
-    def test_perform_merge(self):
+    def make_this_other_directive(self):
         this = self.make_branch_and_tree('this')
         this.commit('first commit')
         other = this.bzrdir.sprout('other').open_workingtree()
-        self.build_tree_contents([('foo', 'bar')])
+        self.build_tree_contents([('other/foo', 'bar')])
+        other.add('foo')
         other.commit('second commit')
         other.lock_write()
         try:
@@ -166,12 +171,31 @@
                                                     0, 'this')
         finally:
             other.unlock()
+        return this, other, directive
+
+    def make_merged_window(self, directive):
         window = MockWindow()
         controller = MergeDirectiveController('directive', directive, window)
         controller.perform_merge(window)
+        return window
+
+    def test_perform_merge_success(self):
+        this, other, directive = self.make_this_other_directive()
+        window = self.make_merged_window(directive)
         self.assertTrue(window.merge_successful)
         self.assertEqual(other.last_revision(), this.get_parent_ids()[1])
-        self.assertFileEqual('bar', 'foo')
+        self.assertFileEqual('bar', 'this/foo')
+
+    def test_perform_merge_conflicts(self):
+        this, other, directive = self.make_this_other_directive()
+        self.build_tree_contents([('this/foo', 'bar')])
+        this.add('foo')
+        this.commit('message')
+        window = self.make_merged_window(directive)
+        self.assertFalse(window.merge_successful)
+        self.assertTrue(window.conflicts)
+        self.assertEqual(other.last_revision(), this.get_parent_ids()[1])
+        self.assertFileEqual('bar', 'this/foo')
 
 
 class Test_IterChangesToStatus(tests.TestCaseWithTransport):

